@@ -19,11 +19,15 @@
 #' 
 #' \strong{my_km2:} Fictitious grid data. 
 #' 
+#' \strong{mun_accidents:} Fictitious traffic accident by municipality data.
+#' 
 #' \strong{sosialFiktiv, z1, z1w, z2, z2w, z3, z3w, z3wb:} See \code{\link{sosialFiktiv}}.
 #' 
+#' \strong{d4, d1, d1w, d2, d2w, d3, d3w, d3wb:} English translation of the datasets above.
+#' 
 #' @export
 #' @importFrom utils data
-#' @author Øyvind Langsrud
+#' @author Øyvind Langsrud and Daniel Lupp
 #'
 #' @examples
 #' SSBtoolsData("FIFA2018ABCD")
@@ -31,7 +35,7 @@
 #' SSBtoolsData("sprt_emp_geoHier")
 #' SSBtoolsData("sprt_emp_ageHier")
 #' SSBtoolsData("sprt_emp_withEU")
-#' SSBtoolsData("z1w")
+#' SSBtoolsData("d1w")
 SSBtoolsData <- function(dataset) {
   if (dataset == "FIFA2018ABCD") {
     return(data.frame(stringsAsFactors = FALSE, mapsFrom = c("Australia", "Iran", "Saudi Arabia", "Egypt", "Morocco", "Nigeria", "Argentina", "Peru", "Uruguay", "Croatia", "Denmark", "France", "Iceland", "Portugal", "Russia", "Spain", "Iceland", "Russia", "Russia", "Croatia", "Europe", "nonEU", "Europe", "nonSchengen"), 
@@ -70,20 +74,90 @@ SSBtoolsData <- function(dataset) {
                             "15_to_65", "15_to_65", "under_15", "under_15", "15_to_65", "15_to_65", "65_and_over", "65_and_over"),
                     Sex = c("female", "male", "male", "female", "male", "female", "male", "female", "male", "female", "female", "male", "female", "male", 
                             "female", "male", "female", "male"),
-                    freq = c(3, 2, 1, 2, 2, 1, 1, 1, 1, 1, 26, 21, 31, 34, 2, 1, 10, 13))
+                    freq = c(3L, 2L, 1L, 2L, 2L, 1L, 1L, 1L, 1L, 1L, 26L, 21L, 31L, 34L, 2L, 1L, 10L, 13L))
     return(x)
   }
   
-  if (dataset %in% c(if (dataset %in% c("sosialFiktiv", "z1", "z1w", "z2", "z2w", "z3", "z3w", "z3wb")) {
-    return(SSBtoolsData_(dataset))
-  })) {
+  if (dataset == "mun_accidents") {
+    mun <- c("k1", "k2", "k3", "k4", "k5", "k6")
+    inj <- c("serious", "light", "none", "unknown")
+    x <- expand.grid(mun, inj, stringsAsFactors = FALSE)
+    names(x) <- c("mun", "inj")
+    x$freq <- c(4L, 5L, 3L, 4L, 1L, 6L, 0L, 0L, 2L, 1L, 0L, 0L, 0L, 1L, 1L, 
+                4L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L)
+    return(x)
+  }
+
+  socialDataset <- c(d4 = "sosialFiktiv", 
+                      d1 = "z1", d1w = "z1w", 
+                      d2 = "z2", d2w = "z2w", 
+                      d3 = "z3", d3w = "z3w", d3wb = "z3wb")
+  
+  if (dataset %in% socialDataset) {
     return(SSBtoolsData_(dataset))
   }
-  
+
+  if (dataset %in% names(socialDataset)) {
+    z <- SSBtoolsData_(socialDataset[dataset])
+    if("hovedint" %in% names(z)){
+      z$hovedint <- SocialReCode(z$hovedint)
+    }
+    names(z) <- SocialReCode(names(z)) 
+    for(i in which(sapply(z, is.numeric))){
+      z[[i]] <- as.integer(z[[i]])
+    }
+    row.names(z) <- NULL
+    return(z)
+  }
+
   stop(paste("No data with dataset =", dataset))
 }
 
 
+#Based on Kostra::CharacterReCode
+SocialReCode <- function(x,oldLevels = names(newLevels), 
+                            newLevels = 
+  # # generated by
+  # z3 <- SSBtoolsData("z3")
+  # z3w <- SSBtoolsData("z3w")
+  # z3wb <- SSBtoolsData("z3wb")
+  # a <- unique(c(names(z3), z3$hovedint, names(z3w), names(z3wb)))
+  # names(a) <- a
+  # # See https://www.ssb.no/en/statbank/table/12203
+  # a <- gsub("fylke", "county", a)
+  # a <- gsub("kostragr", "k_group", a)  # KOSTRA-groups
+  # a <- gsub("hovedint", "main_income", a)  # main source of income
+  # a <- gsub("mnd", "months", a)
+  # a <- gsub("ant", "freq", a)
+  # a <- gsub("annet", "other", a)
+  # a <- gsub("arbeid", "wages", a)  # Norwegian: arbeidsinntekt 
+  # a <- gsub("soshjelp", "assistance", a)  # social assistance
+  # a <- gsub("trygd", "pensions", a)  # Norwegian: trygd/pensjon, English: just pensions
+  # dput(a)
+  c(region = "region", fylke = "county", kostragr = "k_group", 
+    hovedint = "main_income", mnd = "months", mnd2 = "months2", ant = "freq", 
+    annet = "other", arbeid = "wages", soshjelp = "assistance", trygd = "pensions", 
+    annet_m01m05 = "other_m01m05", arbeid_m01m05 = "wages_m01m05", 
+    soshjelp_m01m05 = "assistance_m01m05", trygd_m01m05 = "pensions_m01m05", 
+    annet_m10m12 = "other_m10m12", arbeid_m10m12 = "wages_m10m12", 
+    soshjelp_m10m12 = "assistance_m10m12", trygd_m10m12 = "pensions_m10m12", 
+    annet_m06m09 = "other_m06m09", arbeid_m06m09 = "wages_m06m09", 
+    soshjelp_m06m09 = "assistance_m06m09", trygd_m06m09 = "pensions_m06m09", 
+    annet_m01m05_M01M05 = "other_m01m05_M01M05", arbeid_m01m05_M01M05 = "wages_m01m05_M01M05", 
+    soshjelp_m01m05_M01M05 = "assistance_m01m05_M01M05", trygd_m01m05_M01M05 = "pensions_m01m05_M01M05", 
+    annet_m10m12_M06M12 = "other_m10m12_M06M12", arbeid_m10m12_M06M12 = "wages_m10m12_M06M12", 
+    soshjelp_m10m12_M06M12 = "assistance_m10m12_M06M12", trygd_m10m12_M06M12 = "pensions_m10m12_M06M12", 
+    annet_m06m09_M06M12 = "other_m06m09_M06M12", arbeid_m06m09_M06M12 = "wages_m06m09_M06M12", 
+    soshjelp_m06m09_M06M12 = "assistance_m06m09_M06M12", trygd_m06m09_M06M12 = "pensions_m06m09_M06M12")){
+  x <- as.factor(x)
+  le <- levels(x)
+  ma <- match(le, oldLevels)
+  isMatch <- !is.na(ma)
+  le[isMatch] <- newLevels[ma[isMatch]]
+  levels(x) <- le
+  as.character(x)
+}
+
 
 
 # stackoverflow questions 30357330
@@ -100,8 +174,12 @@ SSBtoolsData_ <- function(dataset) {
 
 #' Fictitious datasets returned by SSBtoolsData()
 #' 
-#' The most comprehensive dataset, \code{sosialFiktiv}, contains three dimensions. The first dimension is 'region' which is grouped in two ways, 'fylke' and  'kostragr'. The other two are 'hovedint' and 'mnd'. In 'mnd2' two of the three categories in 'mnd' are merged.
-#' The other datasets (\code{z1}, \code{z1w}, \code{z2}, \code{z2w}, \code{z3}, \code{z3w}, \code{z3wb}) are smaller subdatasets.
+#' The most comprehensive dataset, \code{sosialFiktiv}, contains three dimensions. 
+#' The first dimension is 'region' which is grouped in two ways, 'fylke' and  
+#' 'kostragr'. The other two are 'hovedint' and 'mnd'. In 'mnd2' two of the 
+#' three categories in 'mnd' are merged.
+#' The other datasets (\code{z1}, \code{z1w}, \code{z2}, \code{z2w}, \code{z3},
+#'  \code{z3w}, \code{z3wb}) are smaller subdatasets.
 #' Datasets marked with '\code{w}' are unstacked and several variables are holding counts.
 #'
 #' @docType data
